{% load static %}

<script type='text/javascript'>
    window.DJANGO_LIVESYNC = {'HOST': '{{ LIVESYNC_SETTINGS.HOST }}', 'PORT': '{{ LIVESYNC_SETTINGS.PORT }}'}
</script>

<script src="{% static 'livesync.js' %}"></script>
